@@ -4,3 +4,6 @@
 #' @importFrom dplyr %>%
 #' @export
 dplyr::`%>%`
+
+#' @import ggplot2
+NULL
